4Suite API Documentation: Ft.Xml.XInclude

4Suite™ API Documentation

# ► Module Ft.Xml.XInclude

XInclude processing

    XInclude processing is normally controlled via the Domlette reader APIs
    and is implemented within Domlette itself. This module just provides
    constants and classes to support XInclude processing.

    XInclude is defined at http://www.w3.org/TR/xinclude

    Copyright 2005 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Globals: NONNORMATIVE_SCHEMA_FOR_XINCLUDE_ELEMENT, XINCLUDE_NAMESPACE

## Globals

NONNORMATIVE_SCHEMA_FOR_XINCLUDE_ELEMENT = '<?xml version="1.0" encoding="utf-8"?>\n<xs:schem...ntents="lax" />\n </xs:complexType>\n\n</xs:schema>'
XINCLUDE_NAMESPACE = u'http://www.w3.org/2001/XInclude'